==> wilmar-in-domain-0.0.86-sources.jar: com/xforceplus/wilmar/entity/GoodsReceive.java <==
package com.xforceplus.wilmar.entity;

import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-06-22
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class GoodsReceive implements Serializable {

  private static final long serialVersionUID=1L;

  private String salesbillNo;

  private String purchasingDocumentNumber;

  private String salesbillItemNo;

  private String plant;

  private String materialDocumentNumber;

  private String materialDocumentYear;

  private String materialDocumentItem;

  private String documentCompareTime;

  private String materialNumber;

  private String materialDescription;

  private String localCurrencyAmount;

  private String carBoatNumber;

  private String itemText;

  private String entryUnit;

  private String receiveQuantity;

  private String lossNumber;

  private String unqualifiedNumber;

  private String movementType;

  private String referenceDocumentYear;

  private String referenceDocumentNumber;

  private String referenceDocumentItem;

  private String debitCreditIndicator;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String tenantCode;




        }

==> wilmar-in-domain-0.0.121-sources.jar: com/xforceplus/wilmar/entity/GoodsReceive.java <==
package com.xforceplus.wilmar.entity;

import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-12
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class GoodsReceive implements Serializable {

  private static final long serialVersionUID=1L;

  private String salesbillNo;

  private String purchasingDocumentNumber;

  private String salesbillItemNo;

  private String plant;

  private String materialDocumentNumber;

  private String materialDocumentYear;

  private String materialDocumentItem;

  private String documentCompareTime;

  private String itemCode;

  private String itemName;

  private String localCurrencyAmount;

  private String carBoatNumber;

  private String itemText;

  private String entryUnit;

  private String receiveQuantity;

  private String lossNumber;

  private String unqualifiedNumber;

  private String movementType;

  private String referenceDocumentYear;

  private String referenceDocumentNumber;

  private String referenceDocumentItem;

  private String debitCreditIndicator;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String tenantCode;

  private String salesbillDetailsId;




        }
